4Suite API Documentation: Ft.Xml.Xslt.StylesheetHandler

4Suite™ API Documentation

# ► Module Ft.Xml.Xslt.StylesheetHandler

Stylesheet tree generator

    Copyright 2004 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Classes: ParseState, StylesheetHandler |  |  |  | Globals: EMPTY_NAMESPACE, XML_NAMESPACE, XSL_NAMESPACE

## Classes

class ParseState
  Stores the current state of the parser.

      Constructor arguments/instance variables:
        validation - validation state for the current containing node.

        localVariables - set of in-scope variable bindings to determine
                         variable shadowing.

        forwardsCompatible - flag indicating whether or not forwards-compatible
                             processing is enabled.

        currentNamespaces - set of in-scope namespaces for the current node.

        extensionNamespaces - set of namespaces defining extension elements

        outputNamespaces - set of in-scope namespaces for literal result elements

  ### Methods

  __init__(self, node, validation, localVariables, forwardsCompatible, currentNamespaces, extensionNamespaces, outputNamespaces)
class StylesheetHandler
  Handles SAX events coming from the stylesheet parser, in order to build the stylesheet tree.

  ### Methods

  __init__(self, importIndex=0, globalVars=None, extElements=None, visitedStyUris=None, altBaseUris=None, ownerDocument=None)
  addExtensionElementMapping(self, elementMapping)
    Add a mapping of extension element names to classes to the existing mapping of extension elements.

        This should only be used for standalone uses of this class.  The
        only known standalone use for this class is for creating compiled
        stylesheets.  The benefits of compiled stylesheets are now so minor
        that this use case may also disappear and then so will this function.
        You have been warned.

  characters(self, data)
  clone(self)
  endDocument(self)
  endElementNS(self, expandedName, qualifiedName)
  getResult(self)
  reset(self)
  setDocumentLocator(self, locator)
  startDocument(self)
    ownerDoc is supplied when processing an XSLT import or include.
  startElementNS(self, expandedName, qualifiedName, attribs)
  startPrefixMapping(self, prefix, uri)

## Globals

EMPTY_NAMESPACE = None
XML_NAMESPACE = u'http://www.w3.org/XML/1998/namespace'
XSL_NAMESPACE = u'http://www.w3.org/1999/XSL/Transform'